import { ScopeEnum } from './common/scopeEnum';
import { Middleware } from 'koa';
import { RequestHandler } from 'express';
export declare type MiddlewareParamArray = Array<Middleware | RequestHandler | string>;
export declare type ObjectIdentifier = string;
/**
 * 内部管理的属性、json、ref等解析实例存储
 */
export interface IManagedInstance {
    type: string;
    value?: any;
    args?: any;
}
export interface ObjectDefinitionOptions {
    isAsync?: boolean;
    initMethod?: string;
    destroyMethod?: string;
    scope?: ScopeEnum;
    constructorArgs?: IManagedInstance[];
    isAutowire?: boolean;
    namespace?: string;
    srcPath?: string;
}
export interface TagPropsMetadata {
    key: string | number | symbol;
    value: any;
    args?: any;
}
export interface TagClsMetadata {
    id: string;
    originName: string;
}
export interface ReflectResult {
    [key: string]: TagPropsMetadata[];
}
export declare enum MSProviderType {
    DUBBO = "dubbo",
    GRPC = "gRPC",
    HSF = "hsf"
}
export declare enum MSListenerType {
    RABBITMQ = "rabbitmq",
    MQTT = "mqtt",
    KAFKA = "kafka",
    REDIS = "redis"
}
export declare namespace ConsumerMetadata {
    interface ConsumerMetadata {
        type: MSListenerType;
        metadata: any;
    }
}
/**
 * grpc decorator metadata format
 */
export declare namespace GRPCMetadata {
    interface ProviderOptions {
        serviceName?: string;
        package?: string;
    }
    interface ProviderMetadata {
        type: MSProviderType;
        metadata: ProviderOptions;
    }
}
export declare namespace FaaSMetadata {
    export interface ServerlessFunctionOptions {
        /**
         * function name
         */
        functionName?: string;
        /**
         * function description
         */
        description?: string;
        /**
         * function memory size, unit: M
         */
        memorySize?: number;
        /**
         * function timeout value, unit: seconds
         */
        timeout?: number;
        /**
         * function init timeout, just for aliyun
         */
        initTimeout?: number;
        /**
         * function runtime, nodejs10, nodejs12, nodejs14
         */
        runtime?: string;
        /**
         * invoke concurrency, just for aliyun
         */
        concurrency?: number;
        /**
         * function invoke stage, like env, just for tencent
         */
        stage?: string;
        /**
         * environment variable, key-value
         */
        environment?: any;
        /**
         * deploy or not
         */
        isDeploy?: boolean;
    }
    interface TriggerCommonOptions {
        /**
         * function name
         */
        functionName?: string;
        /**
         * serverless event name
         */
        name?: string;
        /**
         * function invoke role, just for aliyun
         */
        role?: string;
        /**
         * function publish version, just for aliyun
         */
        version?: string;
        /**
         * deploy or not
         */
        isDeploy?: boolean;
    }
    export interface EventTriggerOptions extends TriggerCommonOptions {
    }
    export interface HTTPTriggerOptions extends TriggerCommonOptions {
        path: string;
        method?: 'get' | 'post' | 'delete' | 'put' | 'head' | 'patch' | 'all';
        middleware?: any[];
    }
    export interface APIGatewayTriggerOptions extends HTTPTriggerOptions {
    }
    export interface OSTriggerOptions extends TriggerCommonOptions {
        bucket: string;
        events: string | string[];
        filter?: {
            prefix: string;
            suffix: string;
        };
    }
    export interface LogTriggerOptions extends TriggerCommonOptions {
        source: string;
        project: string;
        log: string;
        retryTime?: number;
        interval?: number;
    }
    export interface TimerTriggerOptions extends TriggerCommonOptions {
        type: 'cron' | 'every' | 'interval';
        value: string;
        payload?: string;
    }
    export interface MQTriggerOptions extends TriggerCommonOptions {
        topic: string;
        tags?: string;
        region?: string;
        strategy?: 'BACKOFF_RETRY' | 'EXPONENTIAL_DECAY_RETRY';
    }
    export interface HSFTriggerOptions extends TriggerCommonOptions {
    }
    export interface MTopTriggerOptions extends TriggerCommonOptions {
    }
    export interface CDNTriggerOptions extends TriggerCommonOptions {
    }
    export type EventTriggerUnionOptions = EventTriggerOptions | HTTPTriggerOptions | APIGatewayTriggerOptions | OSTriggerOptions | CDNTriggerOptions | LogTriggerOptions | TimerTriggerOptions | MQTriggerOptions | HSFTriggerOptions | MTopTriggerOptions;
    export interface TriggerMetadata {
        type: ServerlessTriggerType;
        functionName?: string;
        methodName: string;
        metadata: EventTriggerUnionOptions;
    }
    export {};
}
export declare enum MidwayFrameworkType {
    WEB = "@midwayjs/web",
    WEB_KOA = "@midwayjs/koa",
    WEB_EXPRESS = "@midwayjs/express",
    FAAS = "@midwayjs/faas",
    MS_HSF = "",
    MS_GRPC = "@midwayjs/grpc",
    MS_RABBITMQ = "@midwayjs/rabbitmq",
    WS_IO = "@midwayjs/socketio",
    WS = "@midwayjs/ws",
    SERVERLESS_APP = "@midwayjs/serverless-app",
    CUSTOM = "",
    EMPTY = "empty",
    LIGHT = "light"
}
export declare enum ServerlessTriggerType {
    EVENT = "event",
    HTTP = "http",
    API_GATEWAY = "apigw",
    OS = "os",
    CDN = "cdn",
    LOG = "log",
    TIMER = "timer",
    MQ = "mq",
    HSF = "hsf",
    MTOP = "mtop"
}
//# sourceMappingURL=interface.d.ts.map